@@ -228,6 +228,13 @@
 #define PR_MAX(x,y)     ((x)>(y)?(x):(y))
 #define PR_ABS(x)       ((x)<0?-(x):(x))
 
+/***********************************************************************
+** MACROS:      PR_ARRAY_SIZE
+** DESCRIPTION:
+**  The number of elements in an array.
+***********************************************************************/
+#define PR_ARRAY_SIZE(a) (sizeof(a)/sizeof((a)[0]))
+
 PR_BEGIN_EXTERN_C
 
 /************************************************************************
@@ -235,7 +242,7 @@ PR_BEGIN_EXTERN_C
 **              PRInt8
 ** DESCRIPTION:
 **  The int8 types are known to be 8 bits each. There is no type that
-**      is equivalent to a plain "char". 
+**      is equivalent to a plain "char".
 ************************************************************************/
 #if PR_BYTES_PER_BYTE == 1
 typedef unsigned char PRUint8;
@@ -274,7 +281,7 @@ typedef signed char PRInt8;
 ** TYPES:       PRUint16
 **              PRInt16
 ** DESCRIPTION:
-**  The int16 types are known to be 16 bits each. 
+**  The int16 types are known to be 16 bits each.
 ************************************************************************/
 #if PR_BYTES_PER_SHORT == 2
 typedef unsigned short PRUint16;
@@ -299,7 +306,7 @@ typedef short PRInt16;
 ** TYPES:       PRUint32
 **              PRInt32
 ** DESCRIPTION:
-**  The int32 types are known to be 32 bits each. 
+**  The int32 types are known to be 32 bits each.
 ************************************************************************/
 #if PR_BYTES_PER_INT == 4
 typedef unsigned int PRUint32;
@@ -344,7 +351,7 @@ typedef long PRInt32;
  * match uint64_t, otherwise our uint64 typedef conflicts with the uint64
  * typedef in cssmconfig.h, which CoreServices.h includes indirectly.
  */
-#if PR_BYTES_PER_LONG == 8 && !defined(__APPLE__)
+#if PR_BYTES_PER_LONG == 8 && !defined(__APPLE__) && !defined(__OpenBSD__)
 typedef long PRInt64;
 typedef unsigned long PRUint64;
 #elif defined(WIN32) && !defined(__GNUC__)
@@ -372,7 +379,7 @@ typedef PRInt64 PRUint64;
 **  The PRIntn types are most appropriate for automatic variables. They are
 **      guaranteed to be at least 16 bits, though various architectures may
 **      define them to be wider (e.g., 32 or even 64 bits). These types are
-**      never valid for fields of a structure. 
+**      never valid for fields of a structure.
 ************************************************************************/
 #if PR_BYTES_PER_INT >= 2
 typedef int PRIntn;
@@ -384,14 +391,14 @@ typedef unsigned int PRUintn;
 /************************************************************************
 ** TYPES:       PRFloat64
 ** DESCRIPTION:
-**  NSPR's floating point type is always 64 bits. 
+**  NSPR's floating point type is always 64 bits.
 ************************************************************************/
 typedef double          PRFloat64;
 
 /************************************************************************
 ** TYPES:       PRSize
 ** DESCRIPTION:
-**  A type for representing the size of objects. 
+**  A type for representing the size of objects.
 ************************************************************************/
 typedef size_t PRSize;
 
@@ -399,7 +406,7 @@ typedef size_t PRSize;
 /************************************************************************
 ** TYPES:       PROffset32, PROffset64
 ** DESCRIPTION:
-**  A type for representing byte offsets from some location. 
+**  A type for representing byte offsets from some location.
 ************************************************************************/
 typedef PRInt32 PROffset32;
 typedef PRInt64 PROffset64;
@@ -408,7 +415,7 @@ typedef PRInt64 PROffset64;
 ** TYPES:       PRPtrDiff
 ** DESCRIPTION:
 **  A type for pointer difference. Variables of this type are suitable
-**      for storing a pointer or pointer subtraction. 
+**      for storing a pointer or pointer subtraction.
 ************************************************************************/
 typedef ptrdiff_t PRPtrdiff;
 
@@ -416,10 +423,10 @@ typedef ptrdiff_t PRPtrdiff;
 ** TYPES:       PRUptrdiff
 ** DESCRIPTION:
 **  A type for pointer difference. Variables of this type are suitable
-**      for storing a pointer or pointer sutraction. 
+**      for storing a pointer or pointer sutraction.
 ************************************************************************/
 #ifdef _WIN64
-typedef unsigned __int64 PRUptrdiff;
+typedef PRUint64 PRUptrdiff;
 #else
 typedef unsigned long PRUptrdiff;
 #endif
@@ -430,7 +437,7 @@ typedef unsigned long PRUptrdiff;
 **  Use PRBool for variables and parameter types. Use PR_FALSE and PR_TRUE
 **      for clarity of target type in assignments and actual arguments. Use
 **      'if (bool)', 'while (!bool)', '(bool) ? x : y' etc., to test booleans
-**      just as you would C int-valued conditions. 
+**      just as you would C int-valued conditions.
 ************************************************************************/
 typedef PRIntn PRBool;
 #define PR_TRUE 1
@@ -445,7 +452,7 @@ typedef PRIntn PRBool;
 typedef PRUint8 PRPackedBool;
 
 /*
-** Status code used by some routines that have a single point of failure or 
+** Status code used by some routines that have a single point of failure or
 ** special status return.
 */
 typedef enum { PR_FAILURE = -1, PR_SUCCESS = 0 } PRStatus;
@@ -471,8 +478,8 @@ typedef PRUint16 PRUnichar;
 ** http://java.sun.com/docs/books/vmspec/index.html.)
 */
 #ifdef _WIN64
-typedef __int64 PRWord;
-typedef unsigned __int64 PRUword;
+typedef PRInt64 PRWord;
+typedef PRUint64 PRUword;
 #else
 typedef long PRWord;
 typedef unsigned long PRUword;
@@ -519,6 +526,14 @@ typedef unsigned long PRUword;
 /********* ????????????? End Fix me ?????????????????????????????? *****/
 #endif /* NO_NSPR_10_SUPPORT */
 
+/*
+** Compile-time assert. "condition" must be a constant expression.
+** The macro can be used only in places where an "extern" declaration is
+** allowed.
+*/
+#define PR_STATIC_ASSERT(condition) \
+    extern void pr_static_assert(int arg[(condition) ? 1 : -1])
+
 PR_END_EXTERN_C
 
 #endif /* prtypes_h___ */
